@@ -1,22 +1,21 @@
-from typing import Optional
-from normality import collapse_spaces
+from normality import squash_spaces
 
 from fingerprints.cleanup import clean_name_ascii
 from fingerprints.types.replacer import get_replacer, NormFunc
 
 
-def replace_types(text: Optional[str]) -> Optional[str]:
+def replace_types(text: str) -> str:
     """Chomp down company types to a more convention form."""
     return get_replacer()(text)
 
 
-def remove_types(
-    text: Optional[str], clean: NormFunc = clean_name_ascii
-) -> Optional[str]:
+def remove_types(text: str, clean: NormFunc = clean_name_ascii) -> str:
     """Remove company type names from a piece of text.
 
     WARNING: This converts to ASCII by default, pass in a different
     `clean` function if you need a different behaviour."""
-    text = clean(text)
-    removed = get_replacer(clean, remove=True)(text)
-    return collapse_spaces(removed)
+    cleaned = clean(text)
+    if cleaned is None:
+        return ""
+    removed = get_replacer(clean, remove=True)(cleaned)
+    return squash_spaces(removed)
